%global debug_package %{nil}

Name: libosinfo
Epoch: 100
Version: 1.9.0
Release: 1%{?dist}
Summary: A library for managing OS information for virtualization
License:  LGPL-2.0-or-later
URL: https://gitlab.com/libosinfo/libosinfo/-/tags
Source0: %{name}_%{version}.orig.tar.gz
%if 0%{?suse_version} > 1500 || 0%{?sle_version} == 150400
BuildRequires: libsoup2-devel
BuildRequires: ninja
%endif
%if 0%{?sle_version} == 150300
BuildRequires: libsoup-devel
BuildRequires: ninja
%endif
%if 0%{?centos_version} == 700
BuildRequires: epel-rpm-macros
BuildRequires: libsoup-devel
BuildRequires: ninja-build
%endif
%if !(0%{?suse_version} > 1500) && !(0%{?sle_version} > 150000) && !(0%{?centos_version} == 700)
BuildRequires: libsoup-devel
BuildRequires: ninja-build
%endif
BuildRequires: gcc
BuildRequires: gettext-devel
BuildRequires: glib2-devel
BuildRequires: gobject-introspection-devel
BuildRequires: gtk-doc
BuildRequires: libxml2-devel >= 2.6.0
BuildRequires: libxslt-devel >= 1.0.0
BuildRequires: lynx
BuildRequires: meson
BuildRequires: osinfo-db
BuildRequires: pciutils
BuildRequires: pkgconfig
BuildRequires: usbutils
BuildRequires: vala
Requires: osinfo-db
Requires: osinfo-db-tools
Requires: pciutils
Requires: usbutils

%description
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%prep
%autosetup -T -c -n %{name}_%{version}-%{release}
tar -zx -f %{S:0} --strip-components=1 -C .

%build
%meson
(
    cd %{_vpath_builddir}
    meson configure -D enable-gtk-doc=true
    meson configure -D enable-tests=true
    meson configure -D enable-introspection=enabled
    meson configure -D enable-vala=enabled
    ninja reconfigure
)
%meson_build

%install
%meson_install

%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150000
%package -n libosinfo-1_0-0
Summary: Operating system and hypervisor information management library
Requires: libosinfo >= %{epoch}:%{version}-%{release}
Requires: pciutils
Requires: usbutils

%description -n libosinfo-1_0-0
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package -n typelib-1_0-Libosinfo-1_0
Summary: Typelib files for libosinfo

%description -n typelib-1_0-Libosinfo-1_0
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package devel
Summary: Header files for libosinfo, an OS/hypervisor information library
Requires: libosinfo-1_0-0 = %{epoch}:%{version}-%{release}
Requires: typelib-1_0-Libosinfo-1_0 = %{epoch}:%{version}-%{release}

%description devel
This package provides includes to compile with the libosinfo library,
as well as Vala bindings for the libosinfo library.

%lang_package

%post -n libosinfo-1_0-0 -p /sbin/ldconfig
%postun -n libosinfo-1_0-0 -p /sbin/ldconfig

%files
%license COPYING
%{_bindir}/osinfo-detect
%{_bindir}/osinfo-install-script
%{_bindir}/osinfo-query
%{_mandir}/man1/osinfo-detect.1*
%{_mandir}/man1/osinfo-install-script.1*
%{_mandir}/man1/osinfo-query.1*

%files -n libosinfo-1_0-0
%{_libdir}/libosinfo-1.0.so.*

%files -n typelib-1_0-Libosinfo-1_0
%{_libdir}/girepository-1.0/Libosinfo-1.0.typelib

%files devel
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/gir-1.0/Libosinfo-1.0.gir
%{_datadir}/gtk-doc/html/Libosinfo/
%{_datadir}/vala/vapi/libosinfo-1.0.deps
%{_datadir}/vala/vapi/libosinfo-1.0.vapi
%{_includedir}/libosinfo-1.0
%{_libdir}/libosinfo-1.0.so
%{_libdir}/pkgconfig/libosinfo-1.0.pc

%files lang
%dir %{_datadir}/locale/*
%dir %{_datadir}/locale/*/LC_MESSAGES
%{_datadir}/locale/*/LC_MESSAGES/libosinfo.mo
%endif

%if !(0%{?suse_version} > 1500) && !(0%{?sle_version} > 150000)
%package devel
Summary: Libraries, includes, etc. to compile with the libosinfo library
Requires: glib2-devel
Requires: libosinfo = %{epoch}:%{version}-%{release}
Requires: pkgconfig
Provides: libosinfo-vala = %{epoch}:%{version}-%{release}

%description devel
Libraries, includes, etc. to compile with the libosinfo library

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_datadir}/locale/*
%dir %{_datadir}/locale/*/LC_MESSAGES
%{_bindir}/osinfo-detect
%{_bindir}/osinfo-install-script
%{_bindir}/osinfo-query
%{_datadir}/locale/*/LC_MESSAGES/libosinfo.mo
%{_libdir}/girepository-1.0/Libosinfo-1.0.typelib
%{_libdir}/libosinfo-1.0.so.*
%{_mandir}/man1/osinfo-detect.1*
%{_mandir}/man1/osinfo-install-script.1*
%{_mandir}/man1/osinfo-query.1*

%files devel
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%dir %{_includedir}/libosinfo-1.0/
%dir %{_includedir}/libosinfo-1.0/osinfo/
%{_datadir}/gir-1.0/Libosinfo-1.0.gir
%{_datadir}/gtk-doc/html/Libosinfo
%{_datadir}/vala/vapi/libosinfo-1.0.deps
%{_datadir}/vala/vapi/libosinfo-1.0.vapi
%{_includedir}/libosinfo-1.0/osinfo/*.h
%{_libdir}/libosinfo-1.0.so
%{_libdir}/pkgconfig/libosinfo-1.0.pc
%endif

%changelog
